==> gorilla-notebook-0.4.0.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.keybindings.js <==
goog.provide('pinkgorilla.keybindings');
goog.require('cljs.core');
goog.require('re_frame.core');
pinkgorilla.keybindings.kb_bind = (function pinkgorilla$keybindings$kb_bind(mousetrap,command){
var temp__5733__auto__ = new cljs.core.Keyword(null,"kb","kb",1183038587).cljs$core$IFn$_invoke$arity$1(command);
if(cljs.core.truth_(temp__5733__auto__)){
var kb = temp__5733__auto__;
var kb_val = ((cljs.core.vector_QMARK_(kb))?cljs.core.clj__GT_js(kb):kb);
var handler = ((cljs.core.vector_QMARK_(new cljs.core.Keyword(null,"handler","handler",-195596612).cljs$core$IFn$_invoke$arity$1(command)))?new cljs.core.Keyword(null,"handler","handler",-195596612).cljs$core$IFn$_invoke$arity$1(command):new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"handler","handler",-195596612).cljs$core$IFn$_invoke$arity$1(command)], null));
return mousetrap.bindGlobal(kb_val,(function (){
return (re_frame.core.dispatch_sync.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.dispatch_sync.cljs$core$IFn$_invoke$arity$1(handler) : re_frame.core.dispatch_sync.call(null,handler));
}));
} else {
return null;
}
});
pinkgorilla.keybindings.install_commands = (function pinkgorilla$keybindings$install_commands(command_keymap){
var temp__5733__auto__ = (cljs.core.truth_((((typeof window !== 'undefined'))?window.Mousetrap:false))?window.Mousetrap:null);
if(cljs.core.truth_(temp__5733__auto__)){
var mousetrap = temp__5733__auto__;
(mousetrap.enabled = true);

(mousetrap.enable = (function (x){
return (mousetrap.enabled = x);
}));

(mousetrap.stopCallback = (function (){
return cljs.core.not(mousetrap.enabled);
}));

return cljs.core.doall.cljs$core$IFn$_invoke$arity$1(cljs.core.map.cljs$core$IFn$_invoke$arity$2(cljs.core.partial.cljs$core$IFn$_invoke$arity$2(pinkgorilla.keybindings.kb_bind,mousetrap),command_keymap));
} else {
return null;
}
});
pinkgorilla.keybindings.all_commands = new cljs.core.PersistentVector(null, 22, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:app:commands",new cljs.core.Keyword(null,"desc","desc",2093485764),"Show the command list.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+g",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"app:commands","app:commands",-313232926)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:evaluator:evaluate",new cljs.core.Keyword(null,"desc","desc",2093485764),"Evaluate the highlighted segment.",new cljs.core.Keyword(null,"kb","kb",1183038587),"shift+enter",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:evaluate","worksheet:evaluate",-1919809293)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:evaluator:evaluate-all",new cljs.core.Keyword(null,"desc","desc",2093485764),"Evaluate all segments.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+shift+enter",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:evaluate-all","worksheet:evaluate-all",792011503)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:worksheet:clear-output",new cljs.core.Keyword(null,"desc","desc",2093485764),"Clear the output of the highlighted segment.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+o",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:clear-output","worksheet:clear-output",1299785235)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:worksheet:clear-all",new cljs.core.Keyword(null,"desc","desc",2093485764),"Clear the output of all code segments.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+z",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:clear-all-output","worksheet:clear-all-output",-104595611)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:worksheet:delete",new cljs.core.Keyword(null,"desc","desc",2093485764),"Delete the highlighted segment.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+x",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:delete","worksheet:delete",-1638532980)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:worksheet:undo",new cljs.core.Keyword(null,"desc","desc",2093485764),"Undo the last segment operation.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+\\",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"undo","undo",-1818036302)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:worksheet:changeToFree",new cljs.core.Keyword(null,"desc","desc",2093485764),"Convert the highlighted segment to a markdown segment.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+m",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:changeToFree","worksheet:changeToFree",1261641395)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:worksheet:changeToCode",new cljs.core.Keyword(null,"desc","desc",2093485764),"Convert the highlighted segment to a clojure segment.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+j",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:changeToCode","worksheet:changeToCode",-926299826)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:app:open",new cljs.core.Keyword(null,"desc","desc",2093485764),"Load a Notebook",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+l",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"browse-files-local","browse-files-local",-871786754)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:app:save",new cljs.core.Keyword(null,"desc","desc",2093485764),"Save the notebook",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+s",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"save-notebook","save-notebook",-481164968)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:app:showsettings",new cljs.core.Keyword(null,"desc","desc",2093485764),"Settings Edit.",new cljs.core.Keyword(null,"kb","kb",1183038587),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["ctrl+1","alt+g alt+1"], null),new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"dialog-show","dialog-show",2118716733),new cljs.core.Keyword(null,"settings","settings",1556144875)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:app:kernel-toggle",new cljs.core.Keyword(null,"desc","desc",2093485764),"Kernel Toggle.",new cljs.core.Keyword(null,"kb","kb",1183038587),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["ctrl+3","alt+g alt+3"], null),new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"app:kernel-toggle","app:kernel-toggle",-267163385)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:app:showmeta",new cljs.core.Keyword(null,"desc","desc",2093485764),"Meta Edit.",new cljs.core.Keyword(null,"kb","kb",1183038587),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["ctrl+2","alt+g alt+2"], null),new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"dialog-show","dialog-show",2118716733),new cljs.core.Keyword(null,"meta","meta",1499536964)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:nav:explore",new cljs.core.Keyword(null,"desc","desc",2093485764),"Explore Notebooks.",new cljs.core.Keyword(null,"kb","kb",1183038587),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["ctrl+4","alt+g alt+4"], null),new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"nav","nav",719540477),"/explore"], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:app:saveas",new cljs.core.Keyword(null,"desc","desc",2093485764),"Save the worksheet to a new filename.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+e",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"app:saveas","app:saveas",-274044344)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:worksheet:newBelow",new cljs.core.Keyword(null,"desc","desc",2093485764),"Create a new segment below the highlighted segment.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+n",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:newBelow","worksheet:newBelow",-1228291898)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:worksheet:newAbove",new cljs.core.Keyword(null,"desc","desc",2093485764),"Create a new segment above the highlighted segment.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+b",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:newAbove","worksheet:newAbove",1338065342)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:worksheet:moveUp",new cljs.core.Keyword(null,"desc","desc",2093485764),"Move the highlighted segment up the worksheet.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+u",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:moveUp","worksheet:moveUp",880608836)], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:worksheet:moveDown",new cljs.core.Keyword(null,"desc","desc",2093485764),"Move the highlighted segment down the worksheet.",new cljs.core.Keyword(null,"kb","kb",1183038587),"alt+g alt+d",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:moveDown","worksheet:moveDown",830176101)], null)], null),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"name","name",1843675177),"command:app:reset-worksheet",new cljs.core.Keyword(null,"desc","desc",2093485764),"Reset the worksheet - a fresh start.",new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"nav","nav",719540477),"/reset"], null)], null),new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"name","name",1843675177),"command:worksheet:completions",new cljs.core.Keyword(null,"desc","desc",2093485764),"Show possible auto-completions.",new cljs.core.Keyword(null,"kb","kb",1183038587),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["ctrl+space","alt+g alt+a"], null),new cljs.core.Keyword(null,"handler","handler",-195596612),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet:completions","worksheet:completions",1282510752)], null)], null)], null);
pinkgorilla.keybindings.command_item = (function pinkgorilla$keybindings$command_item(item){
var kb = new cljs.core.Keyword(null,"kb","kb",1183038587).cljs$core$IFn$_invoke$arity$1(item);
var shortcut = (function (){var or__4185__auto__ = kb;
if(cljs.core.truth_(or__4185__auto__)){
return or__4185__auto__;
} else {
return "&nbsp;";
}
})();
return cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([item,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"text","text",-1790561697),new cljs.core.Keyword(null,"desc","desc",2093485764).cljs$core$IFn$_invoke$arity$1(item),new cljs.core.Keyword(null,"desc","desc",2093485764),["<div class= \"command\" >",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"desc","desc",2093485764).cljs$core$IFn$_invoke$arity$1(item)),"</div><div class= \"command-shortcut\" >",cljs.core.str.cljs$core$IFn$_invoke$arity$1(shortcut),"</div>"].join('')], null)], 0));
});
pinkgorilla.keybindings.visible_commands = cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.PersistentVector.EMPTY,cljs.core.map.cljs$core$IFn$_invoke$arity$2(pinkgorilla.keybindings.command_item,pinkgorilla.keybindings.all_commands));

//# sourceMappingURL=pinkgorilla.keybindings.js.map

==> gorilla-notebook-0.4.8.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.keybindings.js <==
goog.provide('pinkgorilla.keybindings');
goog.require('cljs.core');
goog.require('re_frame.core');
pinkgorilla.keybindings.kb_bind = (function pinkgorilla$keybindings$kb_bind(mousetrap,command){
var temp__5733__auto__ = new cljs.core.Keyword(null,"kb","kb",1183038587).cljs$core$IFn$_invoke$arity$1(command);
if(cljs.core.truth_(temp__5733__auto__)){
var kb = temp__5733__auto__;
var kb_val = ((cljs.core.vector_QMARK_(kb))?cljs.core.clj__GT_js(kb):kb);
var handler = ((cljs.core.vector_QMARK_(new cljs.core.Keyword(null,"handler","handler",-195596612).cljs$core$IFn$_invoke$arity$1(command)))?new cljs.core.Keyword(null,"handler","handler",-195596612).cljs$core$IFn$_invoke$arity$1(command):new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"handler","handler",-195596612).cljs$core$IFn$_invoke$arity$1(command)], null));
return mousetrap.bindGlobal(kb_val,(function (){
return (re_frame.core.dispatch_sync.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.dispatch_sync.cljs$core$IFn$_invoke$arity$1(handler) : re_frame.core.dispatch_sync.call(null,handler));
}));
} else {
return null;
}
});
pinkgorilla.keybindings.install_commands = (function pinkgorilla$keybindings$install_commands(command_keymap){
var temp__5733__auto__ = (cljs.core.truth_((((typeof window !== 'undefined'))?window.Mousetrap:false))?window.Mousetrap:null);
if(cljs.core.truth_(temp__5733__auto__)){
var mousetrap = temp__5733__auto__;
(mousetrap.enabled = true);

(mousetrap.enable = (function (x){
return (mousetrap.enabled = x);
}));

(mousetrap.stopCallback = (function (){
return cljs.core.not(mousetrap.enabled);
}));

return cljs.core.doall.cljs$core$IFn$_invoke$arity$1(cljs.core.map.cljs$core$IFn$_invoke$arity$2(cljs.core.partial.cljs$core$IFn$_invoke$arity$2(pinkgorilla.keybindings.kb_bind,mousetrap),command_keymap));
} else {
return null;
}
});
pinkgorilla.keybindings.command_item = (function pinkgorilla$keybindings$command_item(item){
var kb = new cljs.core.Keyword(null,"kb","kb",1183038587).cljs$core$IFn$_invoke$arity$1(item);
var shortcut = (function (){var or__4185__auto__ = kb;
if(cljs.core.truth_(or__4185__auto__)){
return or__4185__auto__;
} else {
return "&nbsp;";
}
})();
return cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([item,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"text","text",-1790561697),new cljs.core.Keyword(null,"desc","desc",2093485764).cljs$core$IFn$_invoke$arity$1(item),new cljs.core.Keyword(null,"desc","desc",2093485764),["<div class= \"command\" >",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"desc","desc",2093485764).cljs$core$IFn$_invoke$arity$1(item)),"</div><div class= \"command-shortcut\" >",cljs.core.str.cljs$core$IFn$_invoke$arity$1(shortcut),"</div>"].join('')], null)], 0));
});
pinkgorilla.keybindings.visible_commands = (function pinkgorilla$keybindings$visible_commands(commands){
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.PersistentVector.EMPTY,cljs.core.map.cljs$core$IFn$_invoke$arity$2(pinkgorilla.keybindings.command_item,commands));
});

//# sourceMappingURL=pinkgorilla.keybindings.js.map
